@@ -42,7 +42,10 @@ from itertools import count, repeat
 from more_itertools import unzip
 
 
-__version__ = (0, 1)
+APPNAME = __name__
+__version__ = (0, 3)
+VERSION = ".".join(map(str, __version__))
+TESTING = False
 
 
 ## CONSTANTS
@@ -62,22 +65,27 @@ else:
 EMPTY_TUPLE = tuple()  # dummy used in `min` and `max` calls
 INFTY = float("inf")
 NULL_SLICE = slice(None)
-# App-specific constants
-# https://pyinstaller.readthedocs.io/en/stable/runtime-information.html
-APPNAME = __name__
-VERSION = ".".join(map(str, __version__))
-DEFAULT_FRONTENDS = ["PyQt", "curses", "cli"]
-ENTRY_POINT = "play2048"
-IS_FROZEN = getattr(sys, "frozen", False) and hasattr(sys, "_MEIPASS")
-BUNDLE_DIR = Path(sys._MEIPASS) if IS_FROZEN else Path(__file__).parent
-CR = chr(169)  # copyright character
-COPY_FOOTER = (
-    f"{APPNAME}  Copyright {CR} 2021  Daniel Diniz\n"
-    "This program comes with ABSOLUTELY NO WARRANTY.\n"
-    "This is free software, and you are welcome to redistribute it under "
-    "certain conditions."
-)
-TESTING = False
+
+
+__all__ = [
+    # global variables
+    "INFTY",
+    # generic functions
+    "iscontainer",
+    "type_check",
+    "check_int",
+    # exceptions
+    "Base2048Error",
+    "NegativeIntegerError",
+    "ExpectationError",
+    # generic classes
+    "Point",
+    "Directions",
+    "GridIndex",
+    # game grid classes
+    "BaseGameGrid",
+    "SquareGameGrid",
+]
 
 
 ## GENERAL-PURPOSE FUNCTIONS
